package com.ruoyi.voluntary.service;

import java.util.List;
import com.ruoyi.voluntary.domain.SelectedGroup;

/**
 * 科目组合Service接口
 * 
 * @author voluntary
 * @date 2023-03-17
 */
public interface ISelectedGroupService {
    /**
     * 查询科目组合
     * 
     * @param groupId 科目组合主键
     * @return 科目组合
     */
    public SelectedGroup selectSelectedGroupByGroupId(String groupId);

    /**
     * 查询科目组合列表
     * 
     * @param selectedGroup 科目组合
     * @return 科目组合集合
     */
    public List<SelectedGroup> selectSelectedGroupList(SelectedGroup selectedGroup);

    /**
     * 新增科目组合
     * 
     * @param selectedGroup 科目组合
     * @return 结果
     */
    public int insertSelectedGroup(SelectedGroup selectedGroup);

    /**
     * 修改科目组合
     * 
     * @param selectedGroup 科目组合
     * @return 结果
     */
    public int updateSelectedGroup(SelectedGroup selectedGroup);

    /**
     * 批量删除科目组合
     * 
     * @param groupIds 需要删除的科目组合主键集合
     * @return 结果
     */
    public int deleteSelectedGroupByGroupIds(String[] groupIds);

    /**
     * 删除科目组合信息
     * 
     * @param groupId 科目组合主键
     * @return 结果
     */
    public int deleteSelectedGroupByGroupId(String groupId);
}
